"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.orOption = exports.maybeOption = exports.none = exports.some = void 0;
/**
 * Creates a Some.
 * @typeparam T - Type of results.
 * @param x - Value to use.
 * @returns An Option.
 */
function some(x) {
    return { exists: true, value: x };
}
exports.some = some;
/**
 * Creates a None.
 * @returns An Option.
 */
function none() {
    return { exists: false };
}
exports.none = none;
/**
 * Creates an Option from a value that could be null or undefined.
 *
 * ```ts
 * console.log(maybeOption(1));
 * >>> { exists: true, value: 1 }
 *
 * console.log(maybeOption(null));
 * >>> { exists: false }
 *
 * console.log(maybeOption(undefined));
 * >>> { exists: false }
 * ```
 * @param x - A nullable value.
 * @returns An Option.
 */
function maybeOption(x) {
    if (x == null) {
        return none();
    }
    return some(x);
}
exports.maybeOption = maybeOption;
/**
 * Gets the first Some from many Options.
 * @param xs - The Options.
 * @return The first Some, or None if there were no Some.
 */
function orOption(...xs) {
    for (const x of xs) {
        if (x.exists) {
            return x;
        }
    }
    return none();
}
exports.orOption = orOption;
//# sourceMappingURL=option.js.map